summaryrefslogtreecommitdiffstats
path: root/konq-plugins/domtreeviewer/domtreecommands.h
diff options
context:
space:
mode:
Diffstat (limited to 'konq-plugins/domtreeviewer/domtreecommands.h')
-rw-r--r--konq-plugins/domtreeviewer/domtreecommands.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/konq-plugins/domtreeviewer/domtreecommands.h b/konq-plugins/domtreeviewer/domtreecommands.h
index 43af96b..6361fd7 100644
--- a/konq-plugins/domtreeviewer/domtreecommands.h
+++ b/konq-plugins/domtreeviewer/domtreecommands.h
@@ -277,10 +277,10 @@ class ManipulateNodeCommand : public ManipulationCommand
{
public:
/**
* Prepare command, where \c node is to be contained in \c tqparent, just
* before \c after. If \c after is 0, it is appended at the end.
*/
- ManipulateNodeCommand(const DOM::Node &node, const DOM::Node &tqparent, const DOM::Node &after);
+ ManipulateNodeCommand(const DOM::Node &node, const DOM::Node &parent, const DOM::Node &after);
virtual ~ManipulateNodeCommand();
protected:
@@ -304,10 +304,10 @@ class InsertNodeCommand : public ManipulateNodeCommand
{
public:
/**
* Prepare insertion command, inserting \c node into \c tqparent, just
* before \c after. If \c after is 0, append it to the list of tqchildren.
*/
- InsertNodeCommand(const DOM::Node &node, const DOM::Node &tqparent, const DOM::Node &after);
+ InsertNodeCommand(const DOM::Node &node, const DOM::Node &parent, const DOM::Node &after);
virtual ~InsertNodeCommand();
virtual TQString name() const;
@@ -330,10 +330,10 @@ class RemoveNodeCommand : public ManipulateNodeCommand
{
public:
/**
* Prepare insertion command, inserting \c node into \c tqparent, just
* before \c after. If \c after is 0, append it to the list of tqchildren.
*/
- RemoveNodeCommand(const DOM::Node &node, const DOM::Node &tqparent, const DOM::Node &after);
+ RemoveNodeCommand(const DOM::Node &node, const DOM::Node &parent, const DOM::Node &after);
virtual ~RemoveNodeCommand();
virtual TQString name() const;
@@ -353,10 +353,10 @@ class MoveNodeCommand : public ManipulationCommand
{
public:
/**
* Move \c node from current position into \c tqparent, just before \c after.
* Appends if \c after is 0.
*/
- MoveNodeCommand(const DOM::Node &node, const DOM::Node &tqparent, const DOM::Node &after);
+ MoveNodeCommand(const DOM::Node &node, const DOM::Node &parent, const DOM::Node &after);
virtual ~MoveNodeCommand();
virtual TQString name() const;
@@ -277,10 +277,10 @@ class ManipulateNodeCommand : public ManipulationCommand
public:
/**
- * Prepare command, where \c node is to be contained in \c tqparent, just
+ * Prepare command, where \c node is to be contained in \c parent, just
* before \c after. If \c after is 0, it is appended at the end.
*/
@@ -304,10 +304,10 @@ class InsertNodeCommand : public ManipulateNodeCommand
public:
/**
- * Prepare insertion command, inserting \c node into \c tqparent, just
+ * Prepare insertion command, inserting \c node into \c parent, just
* before \c after. If \c after is 0, append it to the list of tqchildren.
*/
@@ -330,10 +330,10 @@ class RemoveNodeCommand : public ManipulateNodeCommand
public:
/**
- * Prepare insertion command, inserting \c node into \c tqparent, just
+ * Prepare insertion command, inserting \c node into \c parent, just
* before \c after. If \c after is 0, append it to the list of tqchildren.
*/
@@ -353,10 +353,10 @@ class MoveNodeCommand : public ManipulationCommand
public:
/**
- * Move \c node from current position into \c tqparent, just before \c after.
+ * Move \c node from current position into \c parent, just before \c after.
* Appends if \c after is 0.
*/